@@ -3,6 +3,7 @@ from typing import Any, Dict, List
 from moto.core.base_backend import BackendDict, BaseBackend
 from moto.core.common_models import BaseModel
 from moto.moto_api._internal import mock_random
+from moto.utilities.utils import get_partition
 
 from .exceptions import DomainNotFound
 
@@ -49,7 +50,7 @@ class Domain(BaseModel):
 
     @property
     def arn(self) -> str:
-        return f"arn:aws:es:{self.region_name}:domain/{self.domain_id}"
+        return f"arn:{get_partition(self.region_name)}:es:{self.region_name}:domain/{self.domain_id}"
 
     def to_json(self) -> Dict[str, Any]:
         return {
@@ -141,5 +142,14 @@ class ElasticsearchServiceBackend(BaseBackend):
         """
         return [{"DomainName": domain.domain_name} for domain in self.domains.values()]
 
+    def describe_elasticsearch_domains(
+        self, domain_names: List[str]
+    ) -> List[Dict[str, Any]]:
+        queried_domains = []
+        for domain_name in domain_names:
+            if domain_name in self.domains:
+                queried_domains.append(self.domains[domain_name].to_json())
+        return queried_domains
+
 
 es_backends = BackendDict(ElasticsearchServiceBackend, "es")
